/**********************************************************************
 *     EPSCAN, an EPSON ES-1200 scanner driver     
 *     Adam P. Jenkins <ajenkins@cs.umass.edu>
 *     
 *     This program is free software; you can redistribute it and/or
 *     modify it under the terms of the GNU General Public License
 *     as published by the Free Software Foundation; either version 2
 *     of the License, or (at your option) any later version.
 *     
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *     
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 **********************************************************************/

#include <qlabel.h>

#include "QLabeledBoxLayout.h"

void
QLabeledBoxLayout::addLabeledWidget(QWidget *w, int stretch,
				    int alignment, const char *label,
				    int labSide, int labAlignment)
{
  QBoxLayout::Direction dir;
  
  if (labSide & AlignLeft) 
    dir = QBoxLayout::LeftToRight;
  else if (labSide & AlignRight)
    dir = QBoxLayout::RightToLeft;
  else if (labSide & AlignTop)
    dir = QBoxLayout::TopToBottom;
  else if (labSide & AlignBottom)
    dir = QBoxLayout::BottomToTop;
  else				// the default
    dir = QBoxLayout::TopToBottom;

  const char *labstring = label ? label : w->name();
  QLabel *lab = new QLabel(labstring, w->parentWidget());
  CHECK_PTR(lab);
  lab->setAlignment(labAlignment);
  lab->adjustSize();
  lab->setMinimumSize(lab->size());
  
  QBoxLayout *lyt = new QBoxLayout(dir, 3);
  CHECK_PTR(lyt);
  addLayout(lyt, stretch);

  lyt->addWidget(lab);
  lyt->addWidget(w, 10, alignment);
}
